@@ -1,5 +1,5 @@
 """
-Often the detector is a lot larger than the reflected intensity peak. 
+Often the detector is a lot larger than the reflected intensity peak.
 Therefore, we crop the image down, these functions help with this.
 """
 
@@ -15,8 +15,10 @@ def crop_2d(array, array_e, x_start=0, x_end=-1, y_start=0, y_end=-1):
     Crop the data (:py:attr:`array`) with some given start and stop point.
 
     Args:
-        array (:py:attr:`array_like`): The intensity map collected by the 2 dimensional detector.
-        array_e (:py:attr:`array_like`): Uncertainty map collected by the 2-D detector.
+        array (:py:attr:`array_like`): The intensity map collected by the 2-D
+            detector.
+        array_e (:py:attr:`array_like`): Uncertainty map collected by the 2-D
+            detector.
         x_start (:py:attr:`int`): Start point in x-axis.
         x_end (:py:attr:`int`): End point in x-axis.
         y_start (:py:attr:`int`): Start point in y-axis.
@@ -38,10 +40,14 @@ def crop_around_peak_2d(array, array_e, x_size=20, y_size=20):
     of dimensions [x_size, y_size].
 
     Args:
-        array (:py:attr:`array_like`): Intensity map collected by the 2 dimensional detector.
-        array_e (:py:attr:`array_like`): Uncertainty map collected by the 2-D detector.
-        x_size (:py:attr:`int`, optional): Size of the cropped image in x-axis. Defaults to :py:attr:`20`.
-        y_size (:py:attr:`int`, optional): Size of the cropped image in y-axis. Defaults to :py:attr:`20`. 
+        array (:py:attr:`array_like`): Intensity map collected by the 2-D
+            detector.
+        array_e (:py:attr:`array_like`): Uncertainty map collected by the 2-D
+            detector.
+        x_size (:py:attr:`int`, optional): Size of the cropped image in x-axis.
+            Defaults to :py:attr:`20`.
+        y_size (:py:attr:`int`, optional): Size of the cropped image in y-axis.
+            Defaults to :py:attr:`20`.
 
     Returns:
         :py:attr:`array_like`: A cropped intensity map.
@@ -50,10 +56,6 @@ def crop_around_peak_2d(array, array_e, x_size=20, y_size=20):
     half_x_size = int(x_size / 2)
     half_y_size = int(y_size / 2)
     return crop_2d(
-            array,
-            array_e,
-            max_inten[1] - half_x_size,
-            max_inten[1] + half_x_size,
-            max_inten[0] - half_y_size,
-            max_inten[0] + half_y_size,
-        )
+        array, array_e, max_inten[1] - half_x_size,
+        max_inten[1] + half_x_size, max_inten[0] - half_y_size,
+        max_inten[0] + half_y_size)
